@@ -28,7 +28,7 @@ def create_column(feature_df, parts_num):
                                      zip(prompt_time_datetime_list, sleep_time_datetime_list)]
     wake_duration = [(y - x).total_seconds() / 60 for x, y in zip(wake_time_datetime_list, sleep_time_datetime_list)]
     duration_per_part = [x // parts_num for x in wake_duration]
-    parts_of_waking_hour_column = [y // x for x, y in zip(duration_per_part, prompt_time_datetime_list)]
+    parts_of_waking_hour_column = [y // x for x, y in zip(duration_per_part, proximity_to_wake_time_column)]
 
     print("     --- success")
 
